local brewer = {}

-- names given in ColorBrewer sites
brewer.names = {    "BuGn", "BuPu", "GnBu", "OrRd", 
                     "PuBu", "PuBuGn", "PuRd", "RdPu", 
                     "YlGn", "YlGnBu", "YlOrBr", 
                     "YlOrRd", "Blues", "Greens", "Greys", 
                     "Oranges", "Purples",  "Reds", 
				     "BrBG", "PiYG", "PRGn", 
                     "PuOr", "RdBu", "RdGy", 
                     "RdYlBu", "RdYlGn", 
                     "Spectral", "Paired", "Pastel1", "Set1", "Set3"}

brewer.divergent = {"BrBG", "PiYG", "PRGn", "PuOr", "RdBu", "RdGy", "RdYlBu", "RdYlGn", "Spectral"}

brewer.sequential = {"BuGn", "BuPu", "GnBu", "OrRd", "PuBu", "PuBuGn", "PuRd", 
                     "RdPu", "YlGn", "YlGnBu", "YlOrBr", "YlOrRd", 
				     "Blues", "Greens", "Greys", "Oranges", "Purples",  "Reds"}

brewer.qualitative = {"Paired", "Pastel1", "Set1", "Set3"}

-- approximate equivalent names in ISCC–NBS system
-- see http://en.wikipedia.org/wiki/ISCC-NBS_system
brewer.isscnames = {"BlueishGreens", "BlueishPurples", "GreenishBlues", "Orangishreds", 
                    "PurplishBlues", "PurplishBluegreens", "PurplishReds", "ReddishPurples",
                    "YellowishGreens", "YellowishGreenblues", "YellowishOrangebrowns", 
                    "YellowishOrangereds", "Blues", "Greens", "Greys", 
                    "Oranges", "Purples",  "Reds",
                    "Browns-White-Bluegreens", "Purples-White-Yellowgreens", "PurplueReds-White-Greens", 
                    "Purples-White-Oranges","Reds-White-Blues","Red-White-Greys",
                    "ReddishYellow-White-Blues", "ReddishYellow-White-Greens", 
                    "Spectral", "Paired", "Pastel1", "Set1", "Set3"}
                
 brewer.matchnames = {
    "BlueishGreens", 
    "BlueishPurples", 
    "GreenishBlues", 
    "Orangishreds",
    "PurplishBlues", 
    "PurplishBluegreens", 
    "PurplishReds", 
    "ReddishPurples",
    "YellowishGreens", 
    "YellowishGreenblues", 
    "YellowishOrangebrowns", 
    "YellowishOrangereds", 
    "Blues", 
    "Greens", 
    "Greys", 
    "Oranges", 
    "Purples",  
    "Reds",
    "Browns-White-Bluegreens", 
    "Purples-White-Yellowgreens", 
    "PurplueReds-White-Greens", 
    "Purples-White-Oranges",
    "Reds-White-Blues",
    "Reds-White-Greys",
    "ReddishYellow-White-Blues", 
    "ReddishYellow-White-Greens", 
    "Spectral", 
    "Paired", 
    "Pastel1", 
    "Set1", 
    "Set3"}

brewer.rgb = { 
   Spectral  = {[3] = {{252,141,89}, {255,255,191}, {153,213,148}}, 
				[4] = {{215,25,28}, {253,174,97}, {171,221,164}, {43,131,186}}, 
				[5] = {{215,25,28}, {253,174,97}, {255,255,191}, {171,221,164}, {43,131,186}}, 
				[6] = {{213,62,79}, {252,141,89}, {254,224,139}, {230,245,152}, {153,213,148}, 
                       {50,136,189}}, 
				[7] = {{213,62,79}, {252,141,89}, {254,224,139}, {255,255,191}, {230,245,152}, 
                       {153,213,148}, {50,136,189}}, 
				[8] = {{213,62,79}, {244,109,67}, {253,174,97}, {254,224,139}, {230,245,152}, 
                       {171,221,164}, {102,194,165}, {50,136,189}}, 
				[9] = {{213,62,79}, {244,109,67}, {253,174,97}, {254,224,139}, {255,255,191}, 
                       {230,245,152}, {171,221,164}, {102,194,165}, {50,136,189}}, 
				[10]= {{158,1,66}, {213,62,79}, {244,109,67}, {253,174,97}, {254,224,139}, 
                       {230,245,152}, {171,221,164}, {102,194,165}, {50,136,189}, {94,79,162}}, 
				[11]= {{158,1,66}, {213,62,79}, {244,109,67}, {253,174,97}, {254,224,139}, {255,255,191}, 
                       {230,245,152}, {171,221,164}, {102,194,165}, {50,136,189}, {94,79,162}}, 
				 type =  "divergent" } ,
	 RdYlGn  = {[3]= {{252,141,89}, {255,255,191}, {145,207,96}}, 
				[4]= {{215,25,28}, {253,174,97}, {166,217,106}, {26,150,65}}, 
				[5]= {{215,25,28}, {253,174,97}, {255,255,191}, {166,217,106}, {26,150,65}}, 
				[6]= {{215,48,39}, {252,141,89}, {254,224,139}, {217,239,139}, {145,207,96}, {26,152,80}}, 
				[7]= {{215,48,39}, {252,141,89}, {254,224,139}, {255,255,191}, {217,239,139}, 
                      {145,207,96}, {26,152,80}}, 
				[8]= {{215,48,39}, {244,109,67}, {253,174,97}, {254,224,139}, {217,239,139}, 
                      {166,217,106}, {102,189,99}, {26,152,80}}, 
				[9]= {{215,48,39}, {244,109,67}, {253,174,97}, {254,224,139}, {255,255,191}, 
                      {217,239,139}, {166,217,106}, {102,189,99}, {26,152,80}}, 
				[10]= {{165,0,38}, {215,48,39}, {244,109,67}, {253,174,97}, {254,224,139}, 
                       {217,239,139}, {166,217,106}, {102,189,99}, {26,152,80}, {0,104,55}}, 
				[11]= {{165,0,38}, {215,48,39}, {244,109,67}, {253,174,97}, {254,224,139}, 
                       {255,255,191}, {217,239,139}, {166,217,106}, {102,189,99}, {26,152,80}, 
                       {0,104,55}}, 
				 type =  "divergent" } ,
	 RdBu =  {  [3]= {{239,138,98}, {247,247,247}, {103,169,207}}, 
				[4]= {{202,0,32}, {244,165,130}, {146,197,222}, {5,113,176}}, 
				[5]= {{202,0,32}, {244,165,130}, {247,247,247}, {146,197,222}, {5,113,176}}, 
				[6]= {{178,24,43}, {239,138,98}, {253,219,199}, {209,229,240}, {103,169,207}, 
                      {33,102,172}}, 
				[7]= {{178,24,43}, {239,138,98}, {253,219,199}, {247,247,247}, {209,229,240}, 
                      {103,169,207}, {33,102,172}}, 
				[8]= {{178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, {209,229,240}, 
                      {146,197,222}, {67,147,195}, {33,102,172}}, 
				[9]= {{178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, {247,247,247}, 
                      {209,229,240}, {146,197,222}, {67,147,195}, {33,102,172}}, 
				[10]= {{103,0,31}, {178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, 
                       {209,229,240}, {146,197,222}, {67,147,195}, {33,102,172}, {5,48,97}}, 
				[11]= {{103,0,31}, {178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, 
                       {247,247,247}, {209,229,240}, {146,197,222}, {67,147,195}, {33,102,172}, 
                       {5,48,97}}, 
				 type =  "divergent" } ,
	 PiYG =  {  [3]= {{233,163,201}, {247,247,247}, {161,215,106}}, 
				[4]= {{208,28,139}, {241,182,218}, {184,225,134}, {77,172,38}}, 
				[5]= {{208,28,139}, {241,182,218}, {247,247,247}, {184,225,134}, {77,172,38}}, 
				[6]= {{197,27,125}, {233,163,201}, {253,224,239}, {230,245,208}, {161,215,106}, 
                      {77,146,33}}, 
				[7]= {{197,27,125}, {233,163,201}, {253,224,239}, {247,247,247}, {230,245,208}, 
                      {161,215,106}, {77,146,33}}, 
				[8]= {{197,27,125}, {222,119,174}, {241,182,218}, {253,224,239}, {230,245,208}, 
                      {184,225,134}, {127,188,65}, {77,146,33}}, 
				[9]= {{197,27,125}, {222,119,174}, {241,182,218}, {253,224,239}, {247,247,247}, 
                      {230,245,208}, {184,225,134}, {127,188,65}, {77,146,33}}, 
				[10]= {{142,1,82}, {197,27,125}, {222,119,174}, {241,182,218}, {253,224,239}, 
                       {230,245,208}, {184,225,134}, {127,188,65}, {77,146,33}, {39,100,25}}, 
				[11]= {{142,1,82}, {197,27,125}, {222,119,174}, {241,182,218}, {253,224,239}, 
                      {247,247,247}, {230,245,208},{184,225,134}, {127,188,65}, {77,146,33}, {39,100,25}}, 
				 type =  "divergent" } ,
	 PRGn =  {	[3]= {{175,141,195}, {247,247,247}, {127,191,123}}, 
				[4]= {{123,50,148}, {194,165,207}, {166,219,160}, {0,136,55}}, 
				[5]= {{123,50,148}, {194,165,207}, {247,247,247}, {166,219,160}, {0,136,55}}, 
				[6]= {{118,42,131}, {175,141,195}, {231,212,232}, {217,240,211}, {127,191,123}, 
                      {27,120,55}}, 
				[7]= {{118,42,131}, {175,141,195}, {231,212,232}, {247,247,247}, {217,240,211}, 
                      {127,191,123}, {27,120,55}}, 
				[8]= {{118,42,131}, {153,112,171}, {194,165,207}, {231,212,232}, {217,240,211}, 
                      {166,219,160}, {90,174,97},
                      {27,120,55}}, 
				[9]= {{118,42,131}, {153,112,171}, {194,165,207}, {231,212,232}, {247,247,247}, 
                      {217,240,211}, {166,219,160}, {90,174,97}, {27,120,55}}, 
				[10]= {{64,0,75}, {118,42,131}, {153,112,171}, {194,165,207}, {231,212,232}, 
                       {217,240,211}, {166,219,160}, {90,174,97}, {27,120,55}, {0,68,27}}, 
				[11]= {{64,0,75}, {118,42,131}, {153,112,171}, {194,165,207}, {231,212,232}, 
                       {247,247,247}, {217,240,211}, {166,219,160}, {90,174,97}, {27,120,55}, {0,68,27}}, 
				 type =  "divergent" } ,
	 RdYlBu =  {[3]= {{252,141,89}, {255,255,191}, {145,191,219}}, 
				[4]= {{215,25,28}, {253,174,97}, {171,217,233}, {44,123,182}}, 
				[5]= {{215,25,28}, {253,174,97}, {255,255,191}, {171,217,233}, {44,123,182}}, 
				[6]= {{215,48,39}, {252,141,89}, {254,224,144}, {224,243,248}, {145,191,219}, 
                      {69,117,180}}, 
				[7]= {{215,48,39}, {252,141,89}, {254,224,144}, {255,255,191}, {224,243,248}, 
                      {145,191,219}, {69,117,180}}, 
				[8]= {{215,48,39}, {244,109,67}, {253,174,97}, {254,224,144}, {224,243,248}, 
                      {171,217,233}, {116,173,209}, {69,117,180}}, 
				[9]= {{215,48,39}, {244,109,67}, {253,174,97}, {254,224,144}, {255,255,191}, 
                      {224,243,248}, {171,217,233}, {116,173,209}, {69,117,180}}, 
				[10]= {{165,0,38}, {215,48,39}, {244,109,67}, {253,174,97}, {254,224,144}, 
                       {224,243,248}, {171,217,233}, {116,173,209}, {69,117,180}, {49,54,149}}, 
				[11]= {{165,0,38}, {215,48,39}, {244,109,67}, {253,174,97}, {254,224,144}, 
                       {255,255,191}, {224,243,248}, {171,217,233}, {116,173,209}, {69,117,180}, {49,54,149}}, 
				 type =  "divergent" } ,
	 BrBG =  {	[3]= {{216,179,101}, {245,245,245}, {90,180,172}}, 
				[4]= {{166,97,26}, {223,194,125}, {128,205,193}, {1,133,113}}, 
				[5]= {{166,97,26}, {223,194,125}, {245,245,245}, {128,205,193}, {1,133,113}}, 
				[6]= {{140,81,10}, {216,179,101}, {246,232,195}, {199,234,229}, {90,180,172}, 
                      {1,102,94}}, 
				[7]= {{140,81,10}, {216,179,101}, {246,232,195}, {245,245,245}, {199,234,229}, 
                      {90,180,172}, {1,102,94}}, 
				[8]= {{140,81,10}, {191,129,45}, {223,194,125}, {246,232,195}, {199,234,229}, 
                      {128,205,193}, {53,151,143}, {1,102,94}}, 
				[9]= {{140,81,10}, {191,129,45}, {223,194,125}, {246,232,195}, {245,245,245}, 
                      {199,234,229}, {128,205,193}, {53,151,143}, {1,102,94}}, 
				[10]= {{84,48,5}, {140,81,10}, {191,129,45}, {223,194,125}, {246,232,195}, 
                       {199,234,229}, {128,205,193}, {53,151,143}, {1,102,94}, {0,60,48}}, 
				[11]= {{84,48,5}, {140,81,10}, {191,129,45}, {223,194,125}, {246,232,195}, 
                       {245,245,245}, {199,234,229}, {128,205,193}, {53,151,143}, {1,102,94}, {0,60,48}}, 
				 type =  "divergent" } ,
	 RdGy =  {	[3]= {{239,138,98}, {255,255,255}, {153,153,153}}, 
				[4]= {{202,0,32}, {244,165,130}, {186,186,186}, {64,64,64}}, 
				[5]= {{202,0,32}, {244,165,130}, {255,255,255}, {186,186,186}, {64,64,64}}, 
				[6]= {{178,24,43}, {239,138,98}, {253,219,199}, {224,224,224}, {153,153,153}, 
                      {77,77,77}}, 
				[7]= {{178,24,43}, {239,138,98}, {253,219,199}, {255,255,255}, {224,224,224}, 
                      {153,153,153}, {77,77,77}}, 
				[8]= {{178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, {224,224,224}, 
                      {186,186,186}, {135,135,135}, {77,77,77}}, 
				[9]= {{178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, {255,255,255}, 
                      {224,224,224}, {186,186,186},  {135,135,135}, {77,77,77}}, 
				[10]= {{103,0,31}, {178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, 
                       {224,224,224}, {186,186,186}, {135,135,135}, {77,77,77}, {26,26,26}}, 
				[11]= {{103,0,31}, {178,24,43}, {214,96,77}, {244,165,130}, {253,219,199}, 
                       {255,255,255}, {224,224,224}, {186,186,186}, {135,135,135}, {77,77,77}, {26,26,26}}, 
				 type =  "divergent" } ,
	 PuOr =  {  [3]= {{241,163,64}, {247,247,247}, {153,142,195}}, 
				[4]= {{230,97,1}, {253,184,99}, {178,171,210}, {94,60,153}}, 
				[5]= {{230,97,1}, {253,184,99}, {247,247,247}, {178,171,210}, {94,60,153}}, 
				[6]= {{179,88,6}, {241,163,64}, {254,224,182}, {216,218,235}, {153,142,195}, 
                      {84,39,136}}, 
				[7]= {{179,88,6}, {241,163,64}, {254,224,182}, {247,247,247}, {216,218,235}, 
                      {153,142,195}, {84,39,136}}, 
				[8]= {{179,88,6}, {224,130,20}, {253,184,99}, {254,224,182}, {216,218,235}, 
                      {178,171,210}, {128,115,172}, {84,39,136}}, 
				[9]= {{179,88,6}, {224,130,20}, {253,184,99}, {254,224,182}, {247,247,247}, 
                      {216,218,235}, {178,171,210}, {128,115,172}, {84,39,136}}, 
				[10]= {{127,59,8}, {179,88,6}, {224,130,20}, {253,184,99}, {254,224,182}, 
                       {216,218,235}, {178,171,210}, {128,115,172}, {84,39,136}, {45,0,75}}, 
				[11]= {{127,59,8}, {179,88,6}, {224,130,20}, {253,184,99}, {254,224,182}, 
                       {247,247,247}, {216,218,235}, {178,171,210}, {128,115,172}, {84,39,136}, {45,0,75}}, 
				 type =  "divergent" } ,
	 Set2 =  {	[3]= {{102,194,165}, {252,141,98}, {141,160,203}}, 
				[4]= {{102,194,165}, {252,141,98}, {141,160,203}, {231,138,195}}, 
				[5]= {{102,194,165}, {252,141,98}, {141,160,203}, {231,138,195}, {166,216,84}}, 
				[6]= {{102,194,165}, {252,141,98}, {141,160,203}, {231,138,195}, {166,216,84}, 
                      {255,217,47}}, 
				[7]= {{102,194,165}, {252,141,98}, {141,160,203}, {231,138,195}, {166,216,84}, 
                      {255,217,47}, {229,196,148}}, 
				[8]= {{102,194,165}, {252,141,98}, {141,160,203}, {231,138,195}, {166,216,84}, 
                      {255,217,47}, {229,196,148}, {179,179,179}}, 
				 type =  "qualitative" } ,
	 Accent = {	[3]= {{127,201,127}, {190,174,212}, {253,192,134}}, 
				[4]= {{127,201,127}, {190,174,212}, {253,192,134}, {255,255,153}}, 
				[5]= {{127,201,127}, {190,174,212}, {253,192,134}, {255,255,153}, {56,108,176}}, 
				[6]= {{127,201,127}, {190,174,212}, {253,192,134}, {255,255,153}, {56,108,176}, 
                      {240,2,127}}, 
				[7]= {{127,201,127}, {190,174,212}, {253,192,134}, {255,255,153}, {56,108,176}, 
                      {240,2,127}, {191,91,23}}, 
				[8]= {{127,201,127}, {190,174,212}, {253,192,134}, {255,255,153}, {56,108,176}, 
                      {240,2,127}, {191,91,23}, {102,102,102}}, 
				 type =  "qualitative" } ,
	 Set1 =  {	[3]= {{228,26,28}, {55,126,184}, {77,175,74}}, 
				[4]= {{228,26,28}, {55,126,184}, {77,175,74}, {152,78,163}}, 
				[5]= {{228,26,28}, {55,126,184}, {77,175,74}, {152,78,163}, {255,127,0}}, 
				[6]= {{228,26,28}, {55,126,184}, {77,175,74}, {152,78,163}, {255,127,0}, 
                      {255,255,51}}, 
				[7]= {{228,26,28}, {55,126,184}, {77,175,74}, {152,78,163}, {255,127,0}, 
                      {255,255,51}, {166,86,40}}, 
				[8]= {{228,26,28}, {55,126,184}, {77,175,74}, {152,78,163}, {255,127,0}, 
                      {255,255,51}, {166,86,40}, {247,129,191}}, 
				[9]= {{228,26,28}, {55,126,184}, {77,175,74}, {152,78,163}, {255,127,0}, 
                      {255,255,51}, {166,86,40}, {247,129,191}, {153,153,153}}, 
				 type =  "qualitative" } ,
	 Set3 =  {	[3]= {{141,211,199}, {255,255,179}, {190,186,218}}, 
				[4]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}}, 
				[5]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}}, 
				[6]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                      {253,180,98}}, 
				[7]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                      {253,180,98}, {179,222,105}}, 
				[8]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                      {253,180,98}, {179,222,105}, {252,205,229}}, 
				[9]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                      {253,180,98}, {179,222,105}, {252,205,229}, {217,217,217}}, 
				[10]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                       {253,180,98}, {179,222,105}, {252,205,229}, {217,217,217}, {188,128,189}}, 
				[11]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                       {253,180,98}, {179,222,105}, {252,205,229}, {217,217,217}, {188,128,189}, 
                       {204,235,197}}, 
				[12]= {{141,211,199}, {255,255,179}, {190,186,218}, {251,128,114}, {128,177,211}, 
                       {253,180,98}, {179,222,105}, {252,205,229}, {217,217,217}, {188,128,189}, 
                       {204,235,197}, {255,237,111}}, 
				 type =  "qualitative" } ,
	 Dark2 =  {	[3]= {{27,158,119}, {217,95,2}, {117,112,179}}, 
				[4]= {{27,158,119}, {217,95,2}, {117,112,179}, {231,41,138}}, 
				[5]= {{27,158,119}, {217,95,2}, {117,112,179}, {231,41,138}, {102,166,30}}, 
				[6]= {{27,158,119}, {217,95,2}, {117,112,179}, {231,41,138}, {102,166,30}, 
                      {230,171,2}}, 
				[7]= {{27,158,119}, {217,95,2}, {117,112,179}, {231,41,138}, {102,166,30}, 
                      {230,171,2}, {166,118,29}}, 
				[8]= {{27,158,119}, {217,95,2}, {117,112,179}, {231,41,138}, {102,166,30}, 
                      {230,171,2}, {166,118,29}, {102,102,102}}, 
				 type =  "qualitative" } ,
	 Paired =  {[3]= {{166,206,227}, {31,120,180}, {178,223,138}}, 
				[4]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}}, 
				[5]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}}, 
				[6]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                      {227,26,28}}, 
				[7]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                      {227,26,28}, {253,191,111}}, 
				[8]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                      {227,26,28}, {253,191,111}, {255,127,0}}, 
				[9]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                      {227,26,28}, {253,191,111}, {255,127,0}, {202,178,214}}, 
				[10]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                       {227,26,28}, {253,191,111}, {255,127,0}, {202,178,214}, {106,61,154}}, 
				[11]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                       {227,26,28}, {253,191,111}, {255,127,0}, {202,178,214}, {106,61,154}, 
                       {255,255,153}}, 
				[12]= {{166,206,227}, {31,120,180}, {178,223,138}, {51,160,44}, {251,154,153}, 
                       {227,26,28}, {253,191,111}, {255,127,0}, {202,178,214}, {106,61,154}, 
                       {255,255,153}, {177,89,40}}, 
				 type =  "qualitative" } ,
	 Pastel2 = {[3]= {{179,226,205}, {253,205,172}, {203,213,232}}, 
				[4]= {{179,226,205}, {253,205,172}, {203,213,232}, {244,202,228}}, 
				[5]= {{179,226,205}, {253,205,172}, {203,213,232}, {244,202,228}, {230,245,201}}, 
				[6]= {{179,226,205}, {253,205,172}, {203,213,232}, {244,202,228}, {230,245,201}, 
                      {255,242,174}}, 
				[7]= {{179,226,205}, {253,205,172}, {203,213,232}, {244,202,228}, {230,245,201}, 
                      {255,242,174}, {241,226,204}}, 
				[8]= {{179,226,205}, {253,205,172}, {203,213,232}, {244,202,228}, {230,245,201}, 
                      {255,242,174}, {241,226,204}, {204,204,204}}, 
				 type =  "qualitative" } ,
	 Pastel1 = {[3]= {{251,180,174}, {179,205,227}, {204,235,197}}, 
				[4]= {{251,180,174}, {179,205,227}, {204,235,197}, {222,203,228}}, 
				[5]= {{251,180,174}, {179,205,227}, {204,235,197}, {222,203,228}, {254,217,166}}, 
				[6]= {{251,180,174}, {179,205,227}, {204,235,197}, {222,203,228}, {254,217,166}, 
                      {255,255,204}}, 
				[7]= {{251,180,174}, {179,205,227}, {204,235,197}, {222,203,228}, {254,217,166}, 
                      {255,255,204}, {229,216,189}}, 
				[8]= {{251,180,174}, {179,205,227}, {204,235,197}, {222,203,228}, {254,217,166}, 
                      {255,255,204}, {229,216,189}, {253,218,236}}, 
				[9]= {{251,180,174}, {179,205,227}, {204,235,197}, {222,203,228}, {254,217,166}, 
                      {255,255,204}, {229,216,189}, {253,218,236}, {242,242,242}}, 
				 type =  "qualitative" } ,

	 OrRd =  {	[3]= {{254,232,200}, {253,187,132}, {227,74,51}}, 
				[4]= {{254,240,217}, {253,204,138}, {252,141,89}, {215,48,31}}, 
				[5]= {{254,240,217}, {253,204,138}, {252,141,89}, {227,74,51}, {179,0,0}}, 
				[6]= {{254,240,217}, {253,212,158}, {253,187,132}, {252,141,89}, {227,74,51}, 
                      {179,0,0}}, 
				[7]= {{254,240,217}, {253,212,158}, {253,187,132}, {252,141,89}, {239,101,72}, 
                      {215,48,31}, {153,0,0}}, 
				[8] = {{255,247,236}, {254,232,200}, {253,212,158}, {253,187,132}, {252,141,89}, 
                      {239,101,72}, {215,48,31}, {153,0,0}}, 
				[9] = {{255,247,236}, {254,232,200}, {253,212,158}, {253,187,132}, {252,141,89}, 
                      {239,101,72}, {215,48,31}, {179,0,0}, {127,0,0}}, 
                [10] = {{255,247,235},{254,235,207},{253,220,176},{253,203,149},{253,182,127},
                        {252,146,93},{243,114,77},{228,79,53},{200,39,24},{153,0,0}},
                [11] = {{255,247,235},{254,236,210},{253,223,183},{253,209,155},{253,192,137},
                        {253,164,110},{249,133,85},{240,105,73},{224,71,47},{196,36,21},{153,0,0}},
                [12] = {{255,247,235},{254,237,213},{254,226,188},{253,213,161},{253,198,143},
                        {253,178,124},{252,149,96},{246,123,81},{236,96,68},{221,64,42},{192,33,19},
                        {153,0,0}},
                [13] = {{255,247,235},{254,238,214},{254,228,192},{253,216,168},{253,203,149},
                        {253,189,134},{253,164,110},{250,137,87},{243,114,77},{233,89,61},
                        {219,58,37},{188,31,18},{153,0,0}},
                [14] = {{255,247,235},{254,238,216},{254,230,196},{253,219,174},{253,208,153},
                        {253,194,139},{253,176,121},{252,151,98},{248,129,83},{241,107,74},{230,82,56},
                        {216,52,34},{185,29,16},{153,0,0}},
                [15] = {{255,247,235},{254,239,217},{254,231,199},{253,221,178},{253,211,158},
                        {253,199,144},{253,186,132},{253,164,110},{252,140,89},{245,121,80},
                        {238,101,71},{227,76,51},{215,48,31},{183,27,15},{153,0,0}},
                [16] = {{255,247,235},{254,239,219},{254,232,202},{253,223,183},
                        {253,214,163},{253,203,149},{253,192,137},{253,174,120},
                        {252,153,100},{249,133,85},{243,114,77},{235,94,66},{224,71,47},
                        {210,45,28},{181,26,14},{153,0,0}},
                [17] = {{255,247,235},{254,240,220},{254,233,204},{254,225,186},
                        {253,216,168},{253,207,153},{253,196,141},{253,184,129},
                        {253,164,110},{252,143,91},{247,126,82},{241,108,75},{233,89,61},
                        {222,66,43},{207,43,27},{179,24,13},{153,0,0}},
                [18] = {{255,247,235},{254,240,221},{254,234,206},{254,227,190},
                        {253,219,172},{253,210,156},{253,200,145},{253,189,135},
                        {253,173,119},{252,154,101},{250,136,86},{245,120,79},
                        {239,103,72},{230,84,57},{220,62,40},{203,41,25},
                        {178,23,12},{153,0,0}},
                [19] = {{255,247,235},{254,241,221},{254,235,207},{254,228,192},
                        {253,220,176},{253,213,160},{253,203,149},{253,193,139},
                        {253,182,127},{253,164,110},{252,146,93},{248,130,84},
                        {243,114,77},{237,98,69},{228,79,53},{219,58,37},{200,39,24},
                        {176,22,11},{153,0,0}},
                [20] = {{255,247,235},{254,241,222},{254,235,209},{254,229,195},
                        {253,222,180},{253,215,164},{253,206,152},{253,197,142},
                        {253,188,133},{253,172,118},{252,155,102},{251,138,88},
                        {246,124,81},{241,109,75},{235,93,65},{226,75,50},
                        {217,54,35},{198,37,22},{175,21,11},{153,0,0}},               
				 type =  "sequential" },
	 PuBu =  {	[3]= {{236,231,242}, {166,189,219}, {43,140,190}}, 
				[4]= {{241,238,246}, {189,201,225}, {116,169,207}, {5,112,176}}, 
				[5]= {{241,238,246}, {189,201,225}, {116,169,207}, {43,140,190}, {4,90,141}}, 
				[6]= {{241,238,246}, {208,209,230}, {166,189,219}, {116,169,207}, {43,140,190}, 
                      {4,90,141}}, 
				[7]= {{241,238,246}, {208,209,230}, {166,189,219}, {116,169,207}, {54,144,192}, 
                      {5,112,176}, {3,78,123}}, 
				[8]= {{255,247,251}, {236,231,242}, {208,209,230}, {166,189,219}, {116,169,207}, 
                      {54,144,192}, {5,112,176}, {3,78,123}}, 
				[9]= {{255,247,251}, {236,231,242}, {208,209,230}, {166,189,219}, {116,169,207}, 
                      {54,144,192}, {5,112,176}, {4,90,141}, {2,56,88}}, 
                [10] = {{255,247,250},{240,234,243},{220,218,235},{194,202,226},
                        {160,186,217},{121,171,208},{78,152,197},{38,129,184},
                        {4,104,163},{2,77,122}},
                [11] = {{255,247,250},{241,235,244},{224,222,237},{203,206,228},
                        {174,192,221},{141,178,213},{105,163,204},{62,146,193},
                        {32,124,182},{4,101,159},{2,77,122}},
                [12] = {{255,247,250},{242,236,245},{228,224,238},{210,210,231},
                        {185,198,224},{157,185,216},{125,172,209},{91,157,200},
                        {51,141,190},{25,120,180},{4,99,156},{2,77,122}},
                [13] = {{255,247,250},{243,237,245},{231,227,239},{214,214,232},
                        {194,202,226},{169,190,219},{141,178,213},{111,166,205},
                        {78,152,197},{45,135,188},{19,117,178},{4,97,153},{2,77,122}},
                [14] = {{255,247,250},{244,238,246},{233,229,241},{218,217,234},
                        {201,205,228},{179,195,222},{155,184,216},{128,173,209},
                        {99,161,202},{66,147,194},{40,131,185},{12,114,177},
                        {4,96,151},{2,77,122}},
                [15] = {{255,247,250},{245,238,246},{235,230,242},{221,219,235},
                        {208,209,229},{187,198,224},{165,189,218},{141,178,213},
                        {115,169,206},{88,156,199},{53,144,191},{36,127,184},
                        {5,112,176},{3,94,149},{2,77,122}},
                [16] = {{255,247,250},{246,239,246},{237,232,242},{224,222,237},
                        {211,211,231},{194,202,226},{174,192,221},{153,183,215},
                        {130,174,210},{105,163,204},{78,152,197},{49,139,189},
                        {32,124,182},{4,109,172},{3,93,147},{2,77,122}},
                [17] = {{255,247,250},{246,239,247},{238,232,243},{227,224,238},
                        {214,214,232},{200,205,227},{181,196,223},{163,187,218},
                        {141,178,213},{119,170,207},{95,159,201},{68,148,194},
                        {45,135,188},{27,121,181},{4,107,169},{3,92,145},{2,77,122}},
                [18] = {{255,247,250},{247,240,247},{239,233,243},{229,225,239},
                        {217,216,234},{205,207,229},{188,199,224},{171,191,220},
                        {151,183,215},{131,174,210},{109,166,205},{86,155,199},
                        {58,145,192},{42,132,186},{23,119,179},{4,105,166},
                        {3,91,144},{2,77,122}},
                [19] = {{255,247,250},{247,240,247},{240,234,243},{231,227,239},
                        {220,218,235},{209,210,230},{194,202,226},{177,194,222},
                        {160,186,217},{141,178,213},{121,171,208},{101,161,202},
                        {78,152,197},{52,142,191},{38,129,184},{19,117,178},
                        {4,104,163},{3,90,143},{2,77,122}},
                [20] = {{255,247,250},{247,241,247},{240,235,244},{233,228,240},
                        {222,220,236},{212,212,231},{199,204,227},{183,197,223},
                        {168,190,219},{150,182,215},{132,175,210},{113,167,206},
                        {93,158,200},{70,149,195},{48,138,189},{35,126,183},
                        {15,115,177},{4,102,161},{3,90,142},{2,77,122}},
				 type =  "sequential" } ,
	 BuPu =  {	[3]= {{224,236,244}, {158,188,218}, {136,86,167}}, 
				[4]= {{237,248,251}, {179,205,227}, {140,150,198}, {136,65,157}}, 
				[5]= {{237,248,251}, {179,205,227}, {140,150,198}, {136,86,167}, {129,15,124}}, 
				[6]= {{237,248,251}, {191,211,230}, {158,188,218}, {140,150,198}, {136,86,167}, 
                      {129,15,124}}, 
				[7]= {{237,248,251}, {191,211,230}, {158,188,218}, {140,150,198}, {140,107,177}, 
                      {136,65,157}, {110,1,107}}, 
				[8]= {{247,252,253}, {224,236,244}, {191,211,230}, {158,188,218}, {140,150,198}, 
                      {140,107,177}, {136,65,157}, {110,1,107}}, 
				[9]= {{247,252,253}, {224,236,244}, {191,211,230}, {158,188,218}, {140,150,198}, 
                      {140,107,177}, {136,65,157}, {129,15,124}, {77,0,75}}, 
                [10] = {{247,252,253},{229,239,245},{205,222,236},{180,203,226},
                        {156,183,215},{142,154,200},{140,121,183},{138,89,168},
                        {130,54,145},{109,0,107}},
                [11] = {{247,252,253},{230,240,246},{210,225,238},{187,208,228},
                        {164,192,220},{149,168,207},{140,141,193},{140,111,179},
                        {138,82,164},{128,50,141},{109,0,107}},
                [12] = {{247,252,253},{232,241,247},{215,229,240},{194,213,231},
                        {173,198,223},{154,181,214},{143,156,201},{140,130,188},
                        {139,103,175},{137,77,162},{126,46,138},{109,0,107}},
                [13] = {{247,252,253},{233,242,247},{218,231,241},{199,217,233},
                        {180,203,226},{160,189,219},{149,168,207},{140,146,196},
                        {140,121,183},{139,97,171},{136,72,160},{125,43,135},{109,0,107}},
                [14] = {{247,252,253},{234,243,248},{221,234,242},{203,220,235},
                        {185,207,228},{168,195,221},{153,179,213},{144,158,202},
                        {140,136,191},{140,113,180},{138,91,169},{136,68,158},
                        {124,41,133},{109,0,107}},
                [15] = {{247,252,253},{235,243,248},{223,235,243},{207,223,236},
                        {191,210,229},{174,199,224},{158,187,217},{149,168,207},
                        {140,150,197},{140,128,187},{140,107,177},{138,86,166},
                        {135,64,157},{123,39,131},{109,0,107}},
                [16] = {{247,252,253},{236,244,248},{225,237,244},{210,225,238},
                        {195,214,231},{180,203,226},{164,192,220},{153,177,212},
                        {144,160,203},{140,141,193},{140,121,183},{139,101,174},
                        {138,82,164},{134,61,153},{122,37,129},{109,0,107}},
                [17] = {{247,252,253},{236,244,249},{226,237,245},{213,228,239},
                        {199,217,233},{184,206,227},{170,196,222},{156,185,216},
                        {149,168,207},{141,152,199},{140,134,190},{140,115,180},
                        {139,97,171},{137,78,163},{132,58,150},{121,35,128},{109,0,107}},
                [18] = {{247,252,253},{237,245,249},{228,238,245},{216,230,240},
                        {202,219,234},{189,209,229},{175,200,224},{161,190,219},
                        {152,176,212},{145,161,203},{140,145,195},{140,127,186},
                        {140,109,178},{139,92,169},{137,75,161},{131,56,147},
                        {121,34,127},{109,0,107}},
                [19] = {{247,252,253},{238,245,249},{229,239,245},{218,231,241},
                        {205,222,236},{192,212,230},{180,203,226},{167,194,221},
                        {156,183,215},{149,168,207},{142,154,200},{140,138,192},
                        {140,121,183},{139,104,175},{138,89,168},{136,72,160},
                        {130,54,145},{120,32,126},{109,0,107}},
                [20] = {{247,252,253},{238,246,249},{230,240,246},{220,233,242},
                        {208,224,237},{196,214,232},{184,206,227},{172,197,223},
                        {159,189,218},{152,175,211},{145,161,204},{140,147,196},
                        {140,132,189},{140,116,181},{139,100,173},{138,85,166},
                        {136,69,159},{129,51,143},{119,31,125},{109,0,107}},
				 type =  "sequential" } ,
	 Oranges = {[3]= {{254,230,206}, {253,174,107}, {230,85,13}}, 
				[4]= {{254,237,222}, {253,190,133}, {253,141,60}, {217,71,1}}, 
				[5]= {{254,237,222}, {253,190,133}, {253,141,60}, {230,85,13}, {166,54,3}}, 
				[6]= {{254,237,222}, {253,208,162}, {253,174,107}, {253,141,60}, {230,85,13}, 
                      {166,54,3}}, 
				[7]= {{254,237,222}, {253,208,162}, {253,174,107}, {253,141,60}, {241,105,19}, 
                      {217,72,1}, {140,45,4}}, 
				[8]= {{255,245,235}, {254,230,206}, {253,208,162}, {253,174,107}, {253,141,60}, 
                      {241,105,19}, {217,72,1}, {140,45,4}}, 
				[9]= {{255,245,235}, {254,230,206}, {253,208,162}, {253,174,107}, {253,141,60}, 
                      {241,105,19}, {217,72,1}, {166,54,3}, {127,39,4}}, 
                [10] = {{255,244,235},{254,233,212},{253,217,181},{253,196,143},{253,170,101},{253,144,65},{245,117,34},{230,90,10},{199,65,2},{140,44,4}},
       [11] = {{255,244,235},{254,234,214},{254,221,188},{253,204,156},{253,180,117},{253,157,83},{250,134,52},{242,108,24},{226,85,7},{193,63,2},{140,44,4}},
       [12] = {{255,244,235},{254,235,216},{254,223,193},{253,209,165},{253,189,131},{253,168,98},{253,147,68},{247,124,43},{238,102,17},{223,81,5},{188,61,2},{140,44,4}},
       [13] = {{255,244,235},{254,236,218},{254,226,198},{253,213,172},{253,196,143},{253,176,111},{253,157,83},{252,138,56},{245,117,34},{235,97,14},{221,77,3},{184,60,2},{140,44,4}},
       [14] = {{255,244,235},{254,236,219},{254,228,202},{253,216,178},{253,202,153},{253,184,123},{253,166,96},{253,148,71},{249,130,48},{242,110,26},{231,92,11},{218,74,2},{180,59,3},{140,44,4}},
       [15] = {{255,244,235},{254,237,220},{254,229,205},{253,218,183},{253,208,161},{253,191,134},{253,173,107},{253,157,83},{253,140,59},{247,123,41},{241,104,19},{229,88,9},{216,71,0},{177,58,3},{140,44,4}},
       [16] = {{255,244,235},{254,237,221},{254,230,207},{254,221,188},{253,210,167},{253,196,143},{253,180,117},{253,165,94},{253,149,72},{250,134,52},{245,117,34},{237,100,16},{226,85,7},{211,70,1},{175,57,3},{140,44,4}},
       [17] = {{255,244,235},{254,238,222},{254,231,209},{254,223,192},{253,213,172},{253,201,151},{253,186,127},{253,171,104},{253,157,83},{253,143,63},{248,127,46},{243,111,28},{235,97,14},{224,82,5},{207,68,1},{172,56,3},{140,44,4}},
       [18] = {{255,244,235},{254,238,223},{254,232,211},{254,224,195},{253,215,177},{253,206,158},{253,192,136},{253,178,113},{253,164,93},{253,150,74},{251,136,55},{246,122,40},{241,107,22},{232,93,12},{222,80,4},{202,67,1},{170,55,3},{140,44,4}},
       [19] = {{255,244,235},{254,239,223},{254,233,212},{254,226,198},{253,217,181},{253,209,164},{253,196,143},{253,183,122},{253,170,101},{253,157,83},{253,144,65},{249,131,49},{245,117,34},{239,103,18},{230,90,10},{221,77,3},{199,65,2},{169,55,3},{140,44,4}},
       [20] = {{255,244,235},{254,239,224},{254,233,213},{254,227,201},{253,219,185},{253,211,168},{253,200,150},{253,188,130},{253,175,109},{253,163,92},{253,151,75},{252,139,58},{248,126,44},{243,112,29},{237,99,16},{228,88,8},{219,75,2},{196,64,2},{167,54,3},{140,44,4}},
				 type =  "sequential" } ,
	 BuGn =  {	[3]= {{229,245,249}, {153,216,201}, {44,162,95}}, 
				[4]= {{237,248,251}, {178,226,226}, {102,194,164}, {35,139,69}}, 
				[5]= {{237,248,251}, {178,226,226}, {102,194,164}, {44,162,95}, {0,109,44}}, 
				[6]= {{237,248,251}, {204,236,230}, {153,216,201}, {102,194,164}, {44,162,95}, 
                      {0,109,44}}, 
				[7]= {{237,248,251}, {204,236,230}, {153,216,201}, {102,194,164}, {65,174,118}, 
                      {35,139,69}, {0,88,36}}, 
				[8]= {{247,252,253}, {229,245,249}, {204,236,230}, {153,216,201}, {102,194,164}, 
                      {65,174,118}, {35,139,69}, {0,88,36}}, 
				[9]= {{247,252,253}, {229,245,249}, {204,236,230}, {153,216,201}, {102,194,164}, 
                      {65,174,118}, {35,139,69}, {0,109,44}, {0,68,27}}, 
				 type =  "sequential" } ,
	 YlOrBr = {	[3]= {{255,247,188}, {254,196,79}, {217,95,14}}, 
				[4]= {{255,255,212}, {254,217,142}, {254,153,41}, {204,76,2}}, 
				[5]= {{255,255,212}, {254,217,142}, {254,153,41}, {217,95,14}, {153,52,4}}, 
				[6]= {{255,255,212}, {254,227,145}, {254,196,79}, {254,153,41}, {217,95,14}, 
                      {153,52,4}}, 
				[7]= {{255,255,212}, {254,227,145}, {254,196,79}, {254,153,41}, {236,112,20}, 
                      {204,76,2}, {140,45,4}}, 
				[8]= {{255,255,229}, {255,247,188}, {254,227,145}, {254,196,79}, {254,153,41}, 
                      {236,112,20}, {204,76,2}, {140,45,4}}, 
				[9]= {{255,255,229}, {255,247,188}, {254,227,145}, {254,196,79}, {254,153,41}, 
                      {236,112,20}, {204,76,2}, {153,52,4}, {102,37,6}}, 
				 type =  "sequential" } ,
	 YlGn =  {	[3]= {{247,252,185}, {173,221,142}, {49,163,84}}, 
				[4]= {{255,255,204}, {194,230,153}, {120,198,121}, {35,132,67}}, 
				[5]= {{255,255,204}, {194,230,153}, {120,198,121}, {49,163,84}, {0,104,55}}, 
				[6]= {{255,255,204}, {217,240,163}, {173,221,142}, {120,198,121}, {49,163,84}, 
                      {0,104,55}}, 
				[7]= {{255,255,204}, {217,240,163}, {173,221,142}, {120,198,121}, {65,171,93}, 
                      {35,132,67}, {0,90,50}}, 
				[8]= {{255,255,229}, {247,252,185}, {217,240,163}, {173,221,142}, {120,198,121}, 
                      {65,171,93}, {35,132,67}, {0,90,50}}, 
				[9]= {{255,255,229}, {247,252,185}, {217,240,163}, {173,221,142}, {120,198,121}, 
                      {65,171,93}, {35,132,67}, {0,104,55}, {0,69,41}}, 
				 type =  "sequential" } ,
	 Reds =  {	[3]= {{254,224,210}, {252,146,114}, {222,45,38}}, 
				[4]= {{254,229,217}, {252,174,145}, {251,106,74}, {203,24,29}}, 
				[5]= {{254,229,217}, {252,174,145}, {251,106,74}, {222,45,38}, {165,15,21}}, 
				[6]= {{254,229,217}, {252,187,161}, {252,146,114}, {251,106,74}, {222,45,38}, 
                      {165,15,21}}, 
				[7]= {{254,229,217}, {252,187,161}, {252,146,114}, {251,106,74}, {239,59,44}, 
                      {203,24,29}, {153,0,13}}, 
				[8]= {{255,245,240}, {254,224,210}, {252,187,161}, {252,146,114}, {251,106,74}, 
                      {239,59,44}, {203,24,29}, {153,0,13}}, 
				[9]= {{255,245,240}, {254,224,210}, {252,187,161}, {252,146,114}, {251,106,74}, 
                      {239,59,44}, {203,24,29}, {165,15,21}, {103,0,13}}, 
				 type =  "sequential" } ,
	 RdPu =  {	[3]= {{253,224,221}, {250,159,181}, {197,27,138}}, 
				[4]= {{254,235,226}, {251,180,185}, {247,104,161}, {174,1,126}}, 
				[5]= {{254,235,226}, {251,180,185}, {247,104,161}, {197,27,138}, {122,1,119}}, 
				[6]= {{254,235,226}, {252,197,192}, {250,159,181}, {247,104,161}, {197,27,138}, 
                      {122,1,119}}, 
				[7]= {{254,235,226}, {252,197,192}, {250,159,181}, {247,104,161}, {221,52,151}, 
                      {174,1,126}, {122,1,119}}, 
				[8]= {{255,247,243}, {253,224,221}, {252,197,192}, {250,159,181}, {247,104,161}, 
                      {221,52,151}, {174,1,126}, {122,1,119}}, 
				[9]= {{255,247,243}, {253,224,221}, {252,197,192}, {250,159,181}, {247,104,161}, 
                      {221,52,151}, {174,1,126}, {122,1,119}, {73,0,106}}, 
				 type =  "sequential" } ,
	 Greens =  {[3]= {{229,245,224}, {161,217,155}, {49,163,84}}, 
				[4]= {{237,248,233}, {186,228,179}, {116,196,118}, {35,139,69}}, 
				[5]= {{237,248,233}, {186,228,179}, {116,196,118}, {49,163,84}, {0,109,44}}, 
				[6]= {{237,248,233}, {199,233,192}, {161,217,155}, {116,196,118}, {49,163,84}, 
                      {0,109,44}}, 
				[7]= {{237,248,233}, {199,233,192}, {161,217,155}, {116,196,118}, {65,171,93}, 
                      {35,139,69}, {0,90,50}}, 
				[8]= {{247,252,245}, {229,245,224}, {199,233,192}, {161,217,155}, {116,196,118}, 
                      {65,171,93}, {35,139,69}, {0,90,50}}, 
				[9]= {{247,252,245}, {229,245,224}, {199,233,192}, {161,217,155}, {116,196,118}, 
                      {65,171,93}, {35,139,69}, {0,109,44}, {0,68,27}}, 
				 type =  "sequential" } ,
	 YlGnBu =  {[3]= {{237,248,177}, {127,205,187}, {44,127,184}}, 
				[4]= {{255,255,204}, {161,218,180}, {65,182,196}, {34,94,168}}, 
				[5]= {{255,255,204}, {161,218,180}, {65,182,196}, {44,127,184}, {37,52,148}}, 
				[6]= {{255,255,204}, {199,233,180}, {127,205,187}, {65,182,196}, {44,127,184}, 
                      {37,52,148}}, 
				[7]= {{255,255,204}, {199,233,180}, {127,205,187}, {65,182,196}, {29,145,192}, 
                      {34,94,168}, {12,44,132}}, 
				[8]= {{255,255,217}, {237,248,177}, {199,233,180}, {127,205,187}, {65,182,196}, 
                      {29,145,192}, {34,94,168}, {12,44,132}}, 
				[9]= {{255,255,217}, {237,248,177}, {199,233,180}, {127,205,187}, {65,182,196}, 
                      {29,145,192}, {34,94,168}, {37,52,148}, {8,29,88}}, 
				 type =  "sequential" } ,
	 Purples = {[3]= {{239,237,245}, {188,189,220}, {117,107,177}}, 
				[4]= {{242,240,247}, {203,201,226}, {158,154,200}, {106,81,163}}, 
				[5]= {{242,240,247}, {203,201,226}, {158,154,200}, {117,107,177}, {84,39,143}}, 
				[6]= {{242,240,247}, {218,218,235}, {188,189,220}, {158,154,200}, {117,107,177}, 
                      {84,39,143}}, 
				[7]= {{242,240,247}, {218,218,235}, {188,189,220}, {158,154,200}, {128,125,186}, 
                      {106,81,163}, {74,20,134}}, 
				[8]= {{252,251,253}, {239,237,245}, {218,218,235}, {188,189,220}, {158,154,200}, 
                      {128,125,186}, {106,81,163}, {74,20,134}}, 
				[9]= {{252,251,253}, {239,237,245}, {218,218,235}, {188,189,220}, {158,154,200}, 
                      {128,125,186}, {106,81,163}, {84,39,143}, {63,0,125}}, 
				 type =  "sequential" } ,
	 GnBu =  {	[3]= {{224,243,219}, {168,221,181}, {67,162,202}}, 
				[4]= {{240,249,232}, {186,228,188}, {123,204,196}, {43,140,190}}, 
				[5]= {{240,249,232}, {186,228,188}, {123,204,196}, {67,162,202}, {8,104,172}}, 
				[6]= {{240,249,232}, {204,235,197}, {168,221,181}, {123,204,196}, {67,162,202}, 
                      {8,104,172}}, 
				[7]= {{240,249,232}, {204,235,197}, {168,221,181}, {123,204,196}, {78,179,211}, 
                      {43,140,190}, {8,88,158}}, 
				[8]= {{247,252,240}, {224,243,219}, {204,235,197}, {168,221,181}, {123,204,196}, 
                      {78,179,211}, {43,140,190}, {8,88,158}}, 
				[9]= {{247,252,240}, {224,243,219}, {204,235,197}, {168,221,181}, {123,204,196}, 
                      {78,179,211}, {43,140,190}, {8,104,172}, {8,64,129}}, 
				 type =  "sequential" } ,
	 Greys =  {	[3]= {{240,240,240}, {189,189,189}, {99,99,99}}, 
				[4]= {{247,247,247}, {204,204,204}, {150,150,150}, {82,82,82}}, 
				[5]= {{247,247,247}, {204,204,204}, {150,150,150}, {99,99,99}, {37,37,37}}, 
				[6]= {{247,247,247}, {217,217,217}, {189,189,189}, {150,150,150}, {99,99,99}, 
                      {37,37,37}}, 
				[7]= {{247,247,247}, {217,217,217}, {189,189,189}, {150,150,150}, {115,115,115}, 
                      {82,82,82}, {37,37,37}}, 
				[8]= {{255,255,255}, {240,240,240}, {217,217,217}, {189,189,189}, {150,150,150}, 
                      {115,115,115}, {82,82,82}, {37,37,37}}, 
				[9]= {{255,255,255}, {240,240,240}, {217,217,217}, {189,189,189}, {150,150,150}, 
                      {115,115,115}, {82,82,82}, {37,37,37}, {0,0,0}}, 
				 type =  "sequential" } ,
	 YlOrRd = {	[3]= {{255,237,160}, {254,178,76}, {240,59,32}}, 
				[4]= {{255,255,178}, {254,204,92}, {253,141,60}, {227,26,28}}, 
				[5]= {{255,255,178}, {254,204,92}, {253,141,60}, {240,59,32}, {189,0,38}}, 
				[6]= {{255,255,178}, {254,217,118}, {254,178,76}, {253,141,60}, {240,59,32}, 
                      {189,0,38}}, 
				[7]= {{255,255,178}, {254,217,118}, {254,178,76}, {253,141,60}, {252,78,42}, 
                      {227,26,28}, {177,0,38}}, 
				[8]= {{255,255,204}, {255,237,160}, {254,217,118}, {254,178,76}, {253,141,60}, 
                      {252,78,42}, {227,26,28}, {177,0,38}}, 
				 type =  "sequential" } ,
	 PuRd =  {	[3]= {{231,225,239}, {201,148,199}, {221,28,119}}, 
				[4]= {{241,238,246}, {215,181,216}, {223,101,176}, {206,18,86}}, 
				[5]= {{241,238,246}, {215,181,216}, {223,101,176}, {221,28,119}, {152,0,67}}, 
				[6]= {{241,238,246}, {212,185,218}, {201,148,199}, {223,101,176}, {221,28,119}, 
                      {152,0,67}},
				[7]= {{241,238,246}, {212,185,218}, {201,148,199}, {223,101,176}, {231,41,138}, 
                      {206,18,86}, {145,0,63}}, 
				[8]= {{247,244,249}, {231,225,239}, {212,185,218}, {201,148,199}, {223,101,176}, 
                      {231,41,138}, {206,18,86}, {145,0,63}}, 
				[9]= {{247,244,249}, {231,225,239}, {212,185,218}, {201,148,199}, {223,101,176}, 
                      {231,41,138}, {206,18,86}, {152,0,67}, {103,0,31}}, 
				 type =  "sequential" } ,
	 Blues = {	[3]= {{222,235,247}, {158,202,225}, {49,130,189}}, 
				[4]= {{239,243,255}, {189,215,231}, {107,174,214}, {33,113,181}}, 
				[5]= {{239,243,255}, {189,215,231}, {107,174,214}, {49,130,189}, {8,81,156}}, 
				[6]= {{239,243,255}, {198,219,239}, {158,202,225}, {107,174,214}, {49,130,189}, 
                      {8,81,156}},
				[7]= {{239,243,255}, {198,219,239}, {158,202,225}, {107,174,214}, {66,146,198}, 
                      {33,113,181}, {8,69,148}}, 
				[8]= {{247,251,255}, {222,235,247}, {198,219,239}, {158,202,225}, {107,174,214}, 
                      {66,146,198}, {33,113,181}, {8,69,148}}, 
                [9]= {{247,251,255}, {222,235,247}, {198,219,239}, {158,202,225}, {107,174,214}, 
                    {66,146,198}, {33,113,181}, {8,81,156}, {8,48,107}},  
                type =  "sequential" } ,
	 PuBuGn = { [3]= {{236,226,240}, {166,189,219}, {28,144,153}}, 
				[4]= {{246,239,247}, {189,201,225}, {103,169,207}, {2,129,138}}, 
				[5]= {{246,239,247}, {189,201,225}, {103,169,207}, {28,144,153}, {1,108,89}}, 
				[6]= {{246,239,247}, {208,209,230}, {166,189,219}, {103,169,207}, {28,144,153}, 
                      {1,108,89}}, 
				[7]= {{246,239,247}, {208,209,230}, {166,189,219}, {103,169,207}, {54,144,192}, 
                      {2,129,138}, {1,100,80}}, 
				[8]= {{255,247,251}, {236,226,240}, {208,209,230}, {166,189,219}, {103,169,207}, 
                      {54,144,192}, {2,129,138}, {1,100,80}}, 
				[9]= {{255,247,251}, {236,226,240}, {208,209,230}, {166,189,219}, {103,169,207}, 
                      {54,144,192}, {2,129,138}, {1,108,89}, {1,70,54}}, 
				 type =  "sequential" } 
}
return brewer