tmepath = os.getenv("TME_PATH_1_3_0")
package.path = package.path .. ";"..tmepath.."/contrib/viewerlib/?.lua;"..tmepath.."/contrib/terrameaddons/?.lua"

local ding   = require ("dingbats")
local gris   = require ("grissom")
local view   = require ("viewer")
local rand   = require ("random")
local agts   = require ("agent_functions")
local cells  = require ("cellspace_functions")
local util   = require ("util")

-- require('mobdebug').loop('giw-camaraimac.uni-muenster.de',8172)
 DIM_SPACE  =  50
 NUM_RUNS   = 100
 WAIT       =  10
 NUM_AGENTS =  30
 MAXAGE     =   8
 
 function growOlder (model)
     forEachAgent (model.soc, function (ag)
                        ag.age = ag.age + 1
                        if ag.age == MAXAGE  then
                            local sons = rand:integer (0,2)
                            if ( sons == 2) then 
                                son1 = ag:reproduce()
                                son1:move (cells.findEmpty (model.cs))
                                son2 = ag:reproduce()
                                son2:move (cells.findEmpty (model.cs))
                            end
                            if (sons == 1) then 
                                son = ag:reproduce()
                                son:move (cells.findEmpty (model.cs))
                            end
                        end
                        if ag.age > MAXAGE then ag:die() end
                    end)
 end

function viewAgents (model)
    forEachAgent (model.soc, function (ag) ag:notify() end)
end
    
    
local model = {}
-- read Sugarscape file - approximates the original Epstein and Axtell grid 
model.cs = cells.fromTxt {
        xdim        = DIM_SPACE, 
        ydim        = DIM_SPACE, 
        attrname    = "maxsugar", 
        txtfile     = "sugar-map.txt", 
        charsize    = 1, 
        whitespaces = 1
    }
    
forEachCell(model.cs, function(cell) cell.color = cell.maxsugar end)
 
 model.cs:createNeighborhood { strategy = "moore" }
 
 
model.agent = Agent {
        init = function(ag)
            ag.wealth     = rand:integer (10, 30 )
            ag.age        = rand:integer (1, 4) 
            ag.placed     = rand:integer (0, 8 )
        end,
        execute = function(ag) 
            ag.age = ag.age + 1
        end
        }

model.soc = Society {
        instance    = model.agent, 
        quantity    = NUM_AGENTS,
        nagents     = 0,
        placed      = 1
    }
 
model.env = Environment { model.cs, model.soc}
model.env:createPlacement { strategy = "random", max = 1} 
 
model.plot = view.Plot { 
            subject = model.soc,
            attributes = {"nagents"}
        }


model.mapcs = view.Map {
            subject   = model.cs,
            attributes = {"color"},
            grouping  = "equalsteps",
            maximum   = 4,
            minimum   = 0,
            slices    = 5,
            values    = {0,1,2,3,4},
            colors    = "Blues"
        }
 

model.sym = view.Symbol {
                subject   = model.agent, 
                attributes = {"age"}, 
                observer  = model.mapcs,
                grouping  = "equalsteps",
                maximum   = 8,
                minimum   = 0, 
                slices    = 9,
                font      = "Grissom Free",
                fontSize  = 30,
                colors    = "Reds",
                symbol    = gris.ANT
        }

model.timer = Timer {
                Event {time = 1, period = 1, priority = 1, 
                        action = function(ev)
                                    model.cs:notify()
                                    agts.randomWalk (model.soc)
                                    model.soc.nagents = agts.count (model.soc)
                                    growOlder (model)
                                    viewAgents (model)
                                    --model.soc:notify(ev:getTime())
                                    util.wait (WAIT)
                                 end
                      }
            }
        
model.timer:execute (NUM_RUNS)

---


